get method
Retrieves the schedule entry with id, or null if absent.
Implementation
@override
Future<ScheduleEntry?> get(String id) async => _entries[id]?.entry;
Retrieves the schedule entry with id, or null if absent.
@override
Future<ScheduleEntry?> get(String id) async => _entries[id]?.entry;