readStep<T> method
Reads a stored step value for the given run.
Implementation
@override
/// Reads a stored step value for the given run.
Future<T?> readStep<T>(String runId, String stepName) async {
final steps = _steps[runId];
if (steps == null) return null;
return steps[stepName] as T?;
}