releaseRun method
Releases the workflow run lease if the owner matches.
Implementation
@override
/// Releases the workflow run lease if the owner matches.
Future<void> releaseRun(String runId, {required String ownerId}) async {
final state = _runs[runId];
if (state == null) return;
if (state.ownerId != ownerId) return;
_runs[runId] = state.copyWith(
ownerId: null,
leaseExpiresAt: null,
updatedAt: _clock.now(),
);
}