saveStep<T> method
Persists a step value and updates the run timestamp.
Implementation
@override
/// Persists a step value and updates the run timestamp.
Future<void> saveStep<T>(String runId, String stepName, T value) async {
_steps[runId]?[stepName] = value;
final state = _runs[runId];
if (state != null) {
_runs[runId] = state.copyWith(updatedAt: _clock.now());
}
}