StemLogLevel enum
Log severity understood by Stem's logging facade.
Values
- debug → const StemLogLevel
-
Diagnostic messages useful during local debugging.
- info → const StemLogLevel
-
Normal operational messages.
- notice → const StemLogLevel
-
Notice-level operational messages.
- warning → const StemLogLevel
-
Recoverable or potentially actionable problems.
- error → const StemLogLevel
-
Errors that prevented an operation from completing normally.
- critical → const StemLogLevel
-
Serious errors requiring attention.
- alert → const StemLogLevel
-
Severe failures requiring immediate attention.
- emergency → const StemLogLevel
-
System-level failures requiring immediate attention.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StemLogLevel> - A constant List of the values in this enum, in order of their declaration.