StemLogger class abstract interface

Dependency-neutral facade for emitting Stem log messages.

The concrete logger and its formatter types are intentionally kept out of Stem's public API. Structured fields should use the fields parameter rather than a logging-library context object; pass structured values through the fields parameter.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alert(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits an alert message.
critical(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits a critical message.
debug(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits a debug message.
emergency(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits an emergency message.
error(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits an error message.
info(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits an informational message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notice(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits a notice message.
toString() String
A string representation of this object.
inherited
warning(Object message, {Map<String, Object?>? fields, StackTrace? stackTrace}) → void
Emits a warning message.

Operators

operator ==(Object other) bool
The equality operator.
inherited