TaskProcessOutcome class sealed

Semantic result of processing one task envelope.

Implementers

Properties

attempt int
Zero-based attempt processed by the handler.
no setter
envelope Envelope
Effective envelope used for this attempt.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskId String
Stable logical task identifier retained across every attempt.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited