TaskRejectionReason enum

Reason a task envelope was rejected before handler execution.

Inheritance
Available extensions

Values

unregisteredTask → const TaskRejectionReason

No handler is registered for the envelope task name.

invalidSignature → const TaskRejectionReason

Envelope signature validation failed.

invalidPayload → const TaskRejectionReason

The encoded task arguments could not be decoded safely.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TaskRejectionReason>
A constant List of the values in this enum, in order of their declaration.