BatchStatus class

Durable batch status projection derived from group metadata/results.

Constructors

BatchStatus({required String batchId, required BatchLifecycleState state, required int expected, required int completed, required int succeededCount, required int failedCount, required int cancelledCount, required List<String> failedTaskIds, required List<String> cancelledTaskIds, required Map<String, Object?> meta})
Creates a durable batch status snapshot.
const

Properties

batchId String
Stable batch identifier.
final
cancelledCount int
Number of children that were cancelled.
final
cancelledTaskIds List<String>
Child task ids that were cancelled.
final
completed int
Number of children currently in terminal states.
final
expected int
Total children expected for the batch.
final
failedCount int
Number of children that failed.
final
failedTaskIds List<String>
Child task ids that failed.
final
hashCode int
The hash code for this object.
no setterinherited
isTerminal bool
Whether the batch is in a terminal state.
no setter
meta Map<String, Object?>
Persisted batch metadata.
final
pendingCount int
Number of children not yet complete.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state BatchLifecycleState
Current batch lifecycle state.
final
succeededCount int
Number of children that succeeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited