BatchSubmission class

Handle returned when a batch is submitted.

Constructors

BatchSubmission({required String batchId, required List<String> taskIds})
Creates a batch submission snapshot.
const

Properties

batchId String
Stable batch identifier.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskIds List<String>
Child task ids dispatched for the batch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited