ClockedScheduleSpec class

Schedule specification for a fixed, absolute run time.

Inheritance

Constructors

ClockedScheduleSpec({required DateTime runAt, bool runOnce = true})
Creates a clocked schedule.
ClockedScheduleSpec.fromJson(Map<String, Object?> json)
Reconstructs a clocked spec from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
The discriminator kind for this specification.
finalinherited
runAt DateTime
The exact time when the task should fire.
final
runOnce bool
Whether the task should only run exactly once. If false, it acts like an interval with a single datum.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? runAt, bool? runOnce}) ClockedScheduleSpec
Returns a copy of this clocked schedule with optional overrides.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes this clocked schedule to JSON-friendly data.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited