GroupStatus class

Aggregated status for a group/chord.

Constructors

GroupStatus({required String id, required int expected, Map<String, TaskStatus>? results, Map<String, Object?>? meta})
Creates a group status snapshot.

Properties

completed int
The number of completed results.
no setter
expected int
The expected number of results.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of the group.
final
isComplete bool
Whether the group is complete.
no setter
meta Map<String, Object?>
Additional metadata for the group.
final
results Map<String, TaskStatus>
The results collected so far.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resultAs<T>({required Codec<T, Object?> codec}) Map<String, T?>
Decodes each collected child result as a typed DTO with codec.
resultJson<T>({required T decode(Map<String, dynamic> payload), String? typeName}) Map<String, T?>
Decodes each collected child result as a typed DTO with a JSON decoder.
resultValues<T>({Codec<T, Object?>? codec}) Map<String, T?>
Returns the decoded payload value for each collected child result.
resultVersionedJson<T>({required int version, required T decode(Map<String, dynamic> payload, int version), int? defaultDecodeVersion, String? typeName}) Map<String, T?>
Decodes each collected child result as a typed DTO with a version-aware JSON decoder.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited