InspectableBroker class abstract interface

Optional broker capability for queue-depth inspection.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

inflightCount(String queue) Future<int?>
Returns the number of in-flight messages for queue, if supported.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pendingCount(String queue) Future<int?>
Returns the number of pending messages for queue, if supported.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited