Middleware class abstract

Middleware hook invoked for lifecycle events around enqueue/consume/execute. Since: 0.1.0

Implementers

Constructors

Middleware()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConsume(Delivery delivery, Future<void> next()) Future<void>
Called when consuming a delivery. Call next to proceed.
onEnqueue(Envelope envelope, Future<void> next()) Future<void>
Called when enqueuing an envelope. Call next to proceed.
onError(TaskContext context, Object error, StackTrace stackTrace) Future<void>
Called when an error occurs during task execution.
onExecute(TaskContext context, Future<void> next()) Future<void>
Called when executing a task with context. Call next to proceed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited