valueOr<T> method
Returns the decoded value for key, or fallback when it is absent.
Implementation
T valueOr<T>(String key, T fallback, {PayloadCodec<T>? codec}) {
return value<T>(key, codec: codec) ?? fallback;
}
Returns the decoded value for key, or fallback when it is absent.
T valueOr<T>(String key, T fallback, {PayloadCodec<T>? codec}) {
return value<T>(key, codec: codec) ?? fallback;
}