PayloadSigner class

Handles signing and verification of envelope payloads.

Constructors

PayloadSigner(SigningConfig config)
Creates a payload signer for the provided config.

Properties

config SigningConfig
Signing configuration used to sign/verify envelopes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Envelope envelope) Future<Envelope>
Returns a copy of envelope with signature headers attached.
toString() String
A string representation of this object.
inherited
verify(Envelope envelope) Future<void>
Validates the envelope signature.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybe(SigningConfig config) PayloadSigner?
Returns a signer when signing is enabled, otherwise null.