QueuePriorityRange class

Priority range constraint applied to a queue definition.

Constructors

QueuePriorityRange({required int min, required int max})
Creates a priority range constraint.
const
QueuePriorityRange.fromJson(Object? value)
Parses a priority range from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
max int
Maximum allowed priority.
final
min int
Minimum allowed priority.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clamp(int value) int
Clamps value to the allowed priority range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, int>
Serializes the priority range to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

standard → const QueuePriorityRange
Default priority range used when none is specified.