RateLimitDecision class

Result of attempting to acquire tokens from the rate limiter.

Constructors

RateLimitDecision({required bool allowed, Duration? retryAfter, Map<String, Object?> meta = const {}})
Creates a rate limit decision outcome.
const

Properties

allowed bool
Whether the acquisition was allowed.
final
hashCode int
The hash code for this object.
no setterinherited
meta Map<String, Object?>
Additional metadata for the decision.
final
retryAfter Duration?
The duration to wait before retrying, if not allowed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited