RouteDefinition class

Declarative routing rule mapping match criteria to targets.

Constructors

RouteDefinition({required RouteMatch match, required RouteTarget target, int? priorityOverride, Map<String, Object?>? options})
Creates a routing rule definition.
RouteDefinition.fromJson(Map<String, Object?> json)
Parses a route definition from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
match RouteMatch
Match criteria evaluated for the route.
final
options Map<String, Object?>
Additional route options.
final
priorityOverride int?
Optional priority override applied to the target.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target RouteTarget
Target to route matching tasks to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes this route definition to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited