ScheduleSpecKind class

Enumerates supported scheduler specification kinds.

These string constants are used in the JSON kind field to identify the polymorphic type of a schedule specification.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

calendar → const String
Calendar-based schedule spec kind (calendar).
clocked → const String
Clocked (single timestamp) schedule spec kind (clocked).
cron → const String
Cron-based schedule spec kind (cron).
interval → const String
Interval-based schedule spec kind (interval).
solar → const String
Solar-based schedule spec kind (solar).