SignalFilter<T extends StemEvent> class

Filters signal emissions based on payload and context.

Constructors

SignalFilter.where(SignalPredicate<T> predicate)
Creates a filter using predicate.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(SignalFilter<T> other) SignalFilter<T>
Combines this filter with other using logical AND.
matches(T payload, SignalContext context) bool
Returns whether the payload passes the filter.
negate() SignalFilter<T>
Negates this filter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allowAll<T extends StemEvent>() SignalFilter<T>
Allows all payloads through the filter.