SolarCalculator class
Computes solar events (sunrise, sunset, solar noon) using NOAA SPA approximations.
Constructors
- SolarCalculator()
-
Creates a solar calculator instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextEvent(
SolarScheduleSpec spec, DateTime fromUtc, Location? location) → DateTime -
Computes the next solar event for the given
spec. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited