StartWorkflowRequest class

Workflow start request payload for isolate communication.

Constructors

StartWorkflowRequest({required String workflowName, required Map<String, Object?> params, String? parentRunId, int? ttlMs, Map<String, Object?>? cancellationPolicy})
Creates a workflow start request payload.
const

Properties

cancellationPolicy Map<String, Object?>?
Optional serialized cancellation policy.
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, Object?>
Encoded workflow params.
final
parentRunId String?
Optional parent workflow run id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlMs int?
Optional run TTL in milliseconds.
final
workflowName String
Workflow name to start.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paramsAs<T>({required PayloadCodec<T> codec}) → T
Decodes the full workflow params payload as a typed DTO with codec.
paramsJson<T>({required T decode(Map<String, dynamic> payload), String? typeName}) → T
Decodes the full workflow params payload as a typed DTO from JSON.
paramsVersionedJson<T>({required int version, required T decode(Map<String, dynamic> payload, int version), int? defaultDecodeVersion, String? typeName}) → T
Decodes the full workflow params payload as a typed DTO from version-aware JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited