StartWorkflowSignal class

Request to start a workflow from an isolate.

Inheritance

Constructors

StartWorkflowSignal(StartWorkflowRequest request, SendPort replyPort)
Creates a workflow start request signal.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
replyPort SendPort
Port to deliver the response.
final
request StartWorkflowRequest
Workflow start request payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited