StemStoreOverrides class

Optional URL overrides for specific store kinds.

Constructors

StemStoreOverrides({String? broker, String? backend, String? workflow, String? schedule, String? lock, String? revoke})
Creates an overrides object for specific store URLs.
const

Properties

backend String?
Override URL for the result backend.
final
broker String?
Override URL for the broker.
final
hashCode int
The hash code for this object.
no setterinherited
lock String?
Override URL for the lock store.
final
revoke String?
Override URL for the revoke store.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule String?
Override URL for the schedule store.
final
workflow String?
Override URL for the workflow store.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited