TaskEnqueueRequest class
Enqueue request payload for isolate communication.
Constructors
Properties
-
args
→ Map<
String, Object?> -
Task arguments.
final
-
enqueueOptions
→ Map<
String, Object?> ? -
Enqueue options.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Task headers.
final
-
meta
→ Map<
String, Object?> -
Task metadata.
final
- name → String
-
Task name to enqueue.
final
- notBefore → DateTime?
-
Optional delay before execution.
final
-
options
→ Map<
String, Object?> -
Task options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
argsAs<
T> ({required PayloadCodec< T> codec}) → T -
Decodes the full task args payload as a typed DTO with
codec. -
argsJson<
T> ({required T decode(Map< String, dynamic> payload), String? typeName}) → T - Decodes the full task args payload as a typed DTO from JSON.
-
argsVersionedJson<
T> ({required int version, required T decode(Map< String, dynamic> payload, int version), int? defaultDecodeVersion, String? typeName}) → T - Decodes the full task args payload as a typed DTO from version-aware JSON.
-
metaAs<
T> ({required PayloadCodec< T> codec}) → T -
Decodes the full task metadata payload as a typed DTO with
codec. -
metaJson<
T> ({required T decode(Map< String, dynamic> payload), String? typeName}) → T - Decodes the full task metadata payload as a typed DTO from JSON.
-
metaVersionedJson<
T> ({required int version, required T decode(Map< String, dynamic> payload, int version), int? defaultDecodeVersion, String? typeName}) → T - Decodes the full task metadata payload as a typed DTO from version-aware JSON.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited