TaskEnqueueScope class

Provides ambient metadata for task enqueue operations.

Use run to scope workflow or tracing metadata so Stem.enqueue can enrich task metadata without requiring explicit plumbing.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

currentMeta() Map<String, Object?>?
Returns the current scoped metadata, if any.
run<R>(Map<String, Object?> meta, R body()) → R
Runs body in a zone that provides meta to task enqueue operations.