TaskMetadata class

Optional task metadata for documentation and tooling.

Constructors

TaskMetadata({String? description, List<String> tags = const [], bool idempotent = false, Map<String, Object?> attributes = const {}, TaskPayloadEncoder? resultEncoder, TaskPayloadEncoder? argsEncoder})
Creates task metadata for documentation and tooling.
const

Properties

argsEncoder TaskPayloadEncoder?
Optional argument encoder override applied when publishing envelopes for this task. When null the runtime falls back to the configured default.
final
attributes Map<String, Object?>
Additional metadata for tooling and dashboards.
final
description String?
Human-readable description of the task.
final
hashCode int
The hash code for this object.
no setterinherited
idempotent bool
Whether the task is safe to execute multiple times with the same args.
final
resultEncoder TaskPayloadEncoder?
Optional result encoder override applied when persisting handler return values. When null the runtime falls back to the configured default.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
Arbitrary tags that describe behavior (e.g. "idempotent", "critical").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited