TaskRegistrationEvent class

Event emitted when a task handler registers with a registry.

Constructors

TaskRegistrationEvent({required String name, required TaskHandler<Object?> handler, required bool overridden})
Creates a registration event snapshot.
const

Properties

handler TaskHandler<Object?>
Handler implementation that was registered.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Logical task name.
final
overridden bool
Whether this registration replaced a previous handler.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited