valueOr method
T
valueOr(
- T fallback
Returns value or fallback when the task has no decoded result.
Implementation
T valueOr(T fallback) => value ?? fallback;
Returns value or fallback when the task has no decoded result.
T valueOr(T fallback) => value ?? fallback;