TaskRetryRequest class

Signals an explicit retry request from within a task handler.

Implemented types

Constructors

TaskRetryRequest({Duration? countdown, DateTime? eta, TaskRetryPolicy? retryPolicy, int? maxRetries, Duration? timeLimit, Duration? softTimeLimit})
Creates a retry request with optional scheduling overrides.

Properties

countdown Duration?
Relative delay before retrying.
final
eta DateTime?
Absolute timestamp for retry.
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int?
Optional max retries override.
final
retryPolicy TaskRetryPolicy?
Optional retry policy override.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softTimeLimit Duration?
Optional soft time limit override.
final
timeLimit Duration?
Optional hard time limit override.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited