TaskRevokedPayload class

Payload emitted when a task is revoked.

Implemented types

Constructors

TaskRevokedPayload({required Envelope envelope, required WorkerInfo worker, required String reason, DateTime? occurredAt})
Creates a new TaskRevokedPayload instance.

Properties

attributes Map<String, Object?>
Event attributes for diagnostics/observability.
no setteroverride
envelope Envelope
The task envelope that was revoked.
final
eventName String
Canonical event name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
occurredAt DateTime
Timestamp when the event occurred.
no setteroverride
reason String
The reason for revoking the task.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
worker WorkerInfo
The worker that was executing the task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited