TlsEnvKeys class abstract

Environment variable keys for TLS configuration.

Constructors

TlsEnvKeys()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

allowInsecure → const String
Environment variable to allow insecure TLS.
caCert → const String
Environment variable for CA certificate path.
clientCert → const String
Environment variable for client certificate path.
clientKey → const String
Environment variable for client private key path.