WorkflowAnnotations class

Collection of workflow-related annotations.

Constructors

WorkflowAnnotations({WorkflowDefn defn = const WorkflowDefn(), WorkflowRun run = const WorkflowRun(), WorkflowStep step = const WorkflowStep()})
Creates the workflow annotation namespace.
const

Properties

defn WorkflowDefn
Marks a class as a workflow definition.
final
hashCode int
The hash code for this object.
no setterinherited
run WorkflowRun
Marks a method as the workflow run entrypoint.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step WorkflowStep
Marks a method as a workflow step.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited