WorkflowIntrospectionSink mixin
Sink for workflow step execution events.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordRuntimeEvent(
WorkflowRuntimeEvent event) → Future< void> -
Records a workflow runtime
event. Optional for sinks that only care about step-level traces. -
recordStepEvent(
WorkflowStepEvent event) → Future< void> -
Records a workflow step execution
event. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited