WorkflowScriptStepSuspensionJson extension

Low-level suspension helpers for workflow script checkpoints.

on

Methods

awaitEventJson<T>(String topic, T value, {DateTime? deadline, String? typeName}) Future<void>

Available on WorkflowScriptStepContext, provided by the WorkflowScriptStepSuspensionJson extension

Suspends the workflow until topic arrives with a DTO payload.
awaitEventVersionedJson<T>(String topic, T value, {required int version, DateTime? deadline, String? typeName}) Future<void>

Available on WorkflowScriptStepContext, provided by the WorkflowScriptStepSuspensionJson extension

Suspends the workflow until topic arrives with a versioned DTO payload.
sleepJson<T>(Duration duration, T value, {String? typeName}) Future<void>

Available on WorkflowScriptStepContext, provided by the WorkflowScriptStepSuspensionJson extension

Suspends the workflow for duration with a JSON-serializable DTO payload.
sleepVersionedJson<T>(Duration duration, T value, {required int version, String? typeName}) Future<void>

Available on WorkflowScriptStepContext, provided by the WorkflowScriptStepSuspensionJson extension

Suspends the workflow for duration with a versioned DTO payload.