withStemClock<T> function
Runs body using clock as the active clock for this zone.
Implementation
T withStemClock<T>(StemClock clock, T Function() body) {
return runZoned(body, zoneValues: {_zoneClockKey: clock});
}
Runs body using clock as the active clock for this zone.
T withStemClock<T>(StemClock clock, T Function() body) {
return runZoned(body, zoneValues: {_zoneClockKey: clock});
}