getGroup method
Returns the group status if it has not expired.
Implementation
@override
/// Returns the group status if it has not expired.
Future<GroupStatus?> getGroup(String groupId) async {
final group = _groups[groupId];
if (group == null) return null;
if (group.expiresAt.isBefore(stemNow())) {
_removeGroup(groupId);
return null;
}
return GroupStatus(
id: groupId,
expected: group.descriptor.expected,
results: Map.unmodifiable(group.results),
meta: group.meta,
);
}