ChordResult<T extends Object?> class
Result returned by Canvas.chord.
Constructors
-
ChordResult({required String chordId, required String callbackTaskId, required List<
T?> values}) -
Creates a chord completion snapshot.
const
Properties
- callbackTaskId → String
-
Identifier of the callback task.
final
- chordId → String
-
Identifier for the chord group.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
T?> -
Results from the chord body tasks.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited