ControlCommandCompletedPayload class
Payload emitted when a control command completes execution.
Constructors
-
ControlCommandCompletedPayload({required WorkerInfo worker, required ControlCommandMessage command, required String status, Map<
String, Object?> ? response, Map<String, Object?> ? error}) -
Creates a new ControlCommandCompletedPayload instance.
const
Properties
- command → ControlCommandMessage
-
The control command that was executed.
final
-
error
→ Map<
String, Object?> ? -
Error information if the command failed, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
response
→ Map<
String, Object?> ? -
The response data from the command execution, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
The status of the command execution (e.g., 'success', 'error').
final
- worker → WorkerInfo
-
The worker that executed the command.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited