ControlCommandReceivedPayload class
Payload emitted when a control command is received by a worker.
- Implemented types
Constructors
- ControlCommandReceivedPayload({required WorkerInfo worker, required ControlCommandMessage command, DateTime? occurredAt})
- Creates a new ControlCommandReceivedPayload instance.
Properties
-
attributes
→ Map<
String, Object?> -
Event attributes for diagnostics/observability.
no setteroverride
- command → ControlCommandMessage
-
The control command that was received.
final
- eventName → String
-
Canonical event name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- occurredAt → DateTime
-
Timestamp when the event occurred.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worker → WorkerInfo
-
The worker that received the command.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited