DeadLetterPage class
Page of dead letter results with optional continuation offset.
Constructors
-
DeadLetterPage({required List<
DeadLetterEntry> entries, int? nextOffset}) -
Creates a page of dead letter entries.
const
Properties
-
entries
→ List<
DeadLetterEntry> -
Entries included in this page.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether additional entries are available.
no setter
- nextOffset → int?
-
Next offset to continue pagination, or
nullif no more entries.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited