ScheduleEntryFailedPayload class
Payload emitted when a schedule entry fails to execute.
- Implemented types
Constructors
- ScheduleEntryFailedPayload({required ScheduleEntry entry, required DateTime scheduledFor, required Object error, required StackTrace stackTrace})
-
Creates a new ScheduleEntryFailedPayload instance.
const
Properties
-
attributes
→ Map<
String, Object?> -
Event attributes for diagnostics/observability.
no setteroverride
- entry → ScheduleEntry
-
The schedule entry that failed.
final
- error → Object
-
The error that caused the failure.
final
- eventName → String
-
Canonical event name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- occurredAt → DateTime
-
Timestamp when the event occurred.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduledFor → DateTime
-
The time for which the entry was scheduled.
final
- stackTrace → StackTrace
-
The stack trace associated with the error.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited