SignalDispatchConfig class
Configuration applied to all signals dispatched through SignalHub.
Constructors
- SignalDispatchConfig({bool enabled = true, void onError(String signalName, Object error, StackTrace stackTrace)?})
-
Creates signal dispatch configuration.
const
Properties
- enabled → bool
-
Whether dispatch is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onError → void Function(String signalName, Object error, StackTrace stackTrace)?
-
Error reporting callback.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enabled, void onError(String signalName, Object error, StackTrace stackTrace)?}) → SignalDispatchConfig - Returns a copy of this config with updated values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited