SigningConfig class
Configuration describing signing keys and behaviour.
This object is typically produced via SigningConfig.fromEnvironment,
which accepts the standard STEM_SIGNING_* environment variables used by
producers and workers:
STEM_SIGNING_KEYSfor HMAC secrets (keyId:base64pairs)STEM_SIGNING_PUBLIC_KEYSandSTEM_SIGNING_PRIVATE_KEYSfor Ed25519STEM_SIGNING_ACTIVE_KEYidentifying the key used for new envelopesSTEM_SIGNING_ALGORITHM(hmac-sha256ored25519)
Producers leverage this configuration through PayloadSigner and will emit warnings plus fail fast when signatures cannot be generated (for example, if the private key for the active Ed25519 key is missing).
Constructors
- SigningConfig.disabled()
-
Disabled configuration (no signing).
const
-
SigningConfig.fromEnvironment(Map<
String, String> env) -
Parses config from environment variables.
factory
Properties
- activeKeyId → String?
-
The active signing key used for new envelopes.
final
- algorithm → SigningAlgorithm
-
Algorithm used to generate signatures.
final
- canSign → bool
-
Whether the current configuration can sign new envelopes.
no setter
-
ed25519PrivateKeys
→ Map<
String, List< int> > -
Ed25519 private keys keyed by identifier.
final
-
ed25519PublicKeys
→ Map<
String, List< int> > -
Ed25519 public keys keyed by identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hmacSecrets
→ Map<
String, List< int> > -
HMAC shared secrets keyed by identifier.
final
- isEnabled → bool
-
Whether signing/verification should be performed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
privateKeyFor(
String keyId) → List< int> ? -
Returns the Ed25519 private key bytes for
keyId, if available. -
publicKeyFor(
String keyId) → List< int> ? -
Returns the Ed25519 public key bytes for
keyId, if available. -
Returns the HMAC secret bytes for
keyId, if available. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited