StemStack class
Resolved factories for a Stem deployment stack.
Constructors
-
StemStack.fromUrl(String url, {Iterable<
StemStoreAdapter> adapters = const [], StemStoreOverrides overrides = const StemStoreOverrides(), bool workflows = false, bool scheduling = false, bool uniqueTasks = false, bool requireRevokeStore = false}) -
Resolves factories from a base URL and adapter list.
factory
Properties
-
adapters
→ List<
StemStoreAdapter> -
Adapters used to resolve this stack.
final
- backend → StemBackendFactory
-
Result backend factory.
final
- broker → StemBrokerFactory
-
Broker factory.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockStore → LockStoreFactory?
-
Optional lock store factory.
final
- revokeStore → RevokeStoreFactory?
-
Optional revoke store factory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleStore → ScheduleStoreFactory?
-
Optional schedule store factory.
final
- workflowStore → WorkflowStoreFactory
-
Workflow store factory.
final
Methods
-
createLockStore(
) → Future< LockStore> - Creates a lock store using the resolved factory.
-
createRevokeStore(
) → Future< RevokeStore> - Creates a revoke store using the resolved factory.
-
createScheduleStore(
) → Future< ScheduleStore> - Creates a schedule store using the resolved factory.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited