StemStoreAdapter class abstract
Adapter that can resolve Stem store factories from a URL.
- Implementers
Constructors
Properties
Methods
-
backendFactory(
Uri uri) → StemBackendFactory? -
Resolves a result backend factory for
uri. -
brokerFactory(
Uri uri) → StemBrokerFactory? -
Resolves a broker factory for
uri. -
lockStoreFactory(
Uri uri) → LockStoreFactory? -
Resolves a lock store factory for
uri. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revokeStoreFactory(
Uri uri) → RevokeStoreFactory? -
Resolves a revoke store factory for
uri. -
scheduleStoreFactory(
Uri uri) → ScheduleStoreFactory? -
Resolves a schedule store factory for
uri. -
supports(
Uri uri, StemStoreKind kind) → bool -
Returns true when the adapter can provide
kindforuri. -
toString(
) → String -
A string representation of this object.
inherited
-
workflowStoreFactory(
Uri uri) → WorkflowStoreFactory? -
Resolves a workflow store factory for
uri.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited