TaskEnqueueBuilder<TArgs, TResult> class
Fluent builder used to construct rich enqueue requests.
Build a TaskCall and dispatch it via TaskEnqueuer.enqueueCall.
- Available extensions
Constructors
-
TaskEnqueueBuilder({required TaskDefinition<
TArgs, TResult> definition, required TArgs args}) - Creates a fluent builder for enqueue calls.
Properties
- args → TArgs
-
Typed arguments for the task invocation.
final
-
definition
→ TaskDefinition<
TArgs, TResult> -
Task definition used to construct the call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → TaskCall< TArgs, TResult> - Builds the TaskCall with accumulated overrides.
-
delay(
Duration duration) → TaskEnqueueBuilder< TArgs, TResult> - Sets a relative delay before execution.
-
enqueueOptions(
TaskEnqueueOptions options) → TaskEnqueueBuilder< TArgs, TResult> - Replaces the enqueue options for this call.
-
enqueueWith(
TaskEnqueuer enqueuer) → Future< String> -
Available on TaskEnqueueBuilder<
Builds the call and enqueues it with the providedTArgs, TResult> , provided by the TaskEnqueueBuilderExtension extensionenqueuerinstance. -
header(
String key, String value) → TaskEnqueueBuilder< TArgs, TResult> - Adds or overrides a single header entry.
-
headers(
Map< String, String> headers) → TaskEnqueueBuilder<TArgs, TResult> - Replaces headers entirely.
-
meta(
String key, Object? value) → TaskEnqueueBuilder< TArgs, TResult> - Adds or overrides a metadata entry.
-
metadata(
Map< String, Object?> meta) → TaskEnqueueBuilder<TArgs, TResult> - Replaces metadata entirely.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notBefore(
DateTime instant) → TaskEnqueueBuilder< TArgs, TResult> - Sets the earliest execution time.
-
options(
TaskOptions options) → TaskEnqueueBuilder< TArgs, TResult> - Replaces the options for this call.
-
priority(
int priority) → TaskEnqueueBuilder< TArgs, TResult> - Sets the priority for this enqueue.
-
queue(
String queue) → TaskEnqueueBuilder< TArgs, TResult> - Sets the queue for this enqueue.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited