TaskEnqueueRequest class

Enqueue request payload for isolate communication.

Constructors

TaskEnqueueRequest({required String name, required Map<String, Object?> args, required Map<String, String> headers, required Map<String, Object?> options, required Map<String, Object?> meta, Map<String, Object?>? enqueueOptions})
Creates an enqueue request payload.
const

Properties

args Map<String, Object?>
Task arguments.
final
enqueueOptions Map<String, Object?>?
Enqueue options.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Task headers.
final
meta Map<String, Object?>
Task metadata.
final
name String
Task name to enqueue.
final
options Map<String, Object?>
Task options.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited