TaskFailurePayload class
Payload emitted when a task fails.
- Implemented types
Constructors
- TaskFailurePayload({required Envelope envelope, required WorkerInfo worker, required Object error, required StackTrace? stackTrace, DateTime? occurredAt})
- Creates a new TaskFailurePayload instance.
Properties
- attempt → int
-
The attempt number for this task execution.
no setter
-
attributes
→ Map<
String, Object?> -
Event attributes for diagnostics/observability.
no setteroverride
- envelope → Envelope
-
The task envelope that failed.
final
- error → Object
-
The error that caused the task to fail.
final
- eventName → String
-
Canonical event name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- occurredAt → DateTime
-
Timestamp when the event occurred.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace associated with the failure, if available.
final
- taskId → String
-
The unique identifier for the task.
no setter
- taskName → String
-
The name of the task.
no setter
- worker → WorkerInfo
-
The worker that executed the task.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited