TaskReceivedPayload class
Payload emitted when a task is received by a worker.
Constructors
- TaskReceivedPayload({required Envelope envelope, required WorkerInfo worker})
-
Creates a new TaskReceivedPayload instance.
const
Properties
- envelope → Envelope
-
The task envelope that was received.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
The unique identifier for the task.
no setter
- taskName → String
-
The name of the task.
no setter
- worker → WorkerInfo
-
The worker that received the task.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited