Shared typed task-dispatch surface used by producers, apps, and contexts.
This compatibility contract combines StemProducer and StemObserver. New application boundaries should prefer one of those narrower roles.
- Implemented types
- Implementers
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enqueue(
String name, {Map< String, Object?> args, Map<String, String> headers, TaskOptions options, DateTime? notBefore, Map<String, Object?> meta, TaskEnqueueOptions? enqueueOptions}) → Future<String> -
Enqueue a task by name.
inherited
-
enqueueCall<
TArgs, TResult> (TaskCall< TArgs, TResult> call, {TaskEnqueueOptions? enqueueOptions}) → Future<String> -
Enqueue a typed task call.
inherited
-
enqueueJson<
T extends Object> (String name, T argsJson, {Map< String, String> headers = const {}, TaskOptions options = const TaskOptions(), DateTime? notBefore, Map<String, Object?> meta = const {}, TaskEnqueueOptions? enqueueOptions, String? typeName}) → Future<String> -
Available on TaskEnqueuer, provided by the TaskEnqueuerBuilderExtension extension
Enqueues a name-based task from a DTO that already exposestoJson(). -
enqueueValue<
T> (String name, T value, {PayloadCodec< T> ? codec, Map<String, String> headers, TaskOptions options, DateTime? notBefore, Map<String, Object?> meta, TaskEnqueueOptions? enqueueOptions}) → Future<String> -
Enqueue a dynamic-name task using a typed value plus optional
codec.inherited -
enqueueVersionedJson<
T extends Object> (String name, T argsJson, {required int version, Map< String, String> headers = const {}, TaskOptions options = const TaskOptions(), DateTime? notBefore, Map<String, Object?> meta = const {}, TaskEnqueueOptions? enqueueOptions, String? typeName}) → Future<String> -
Available on TaskEnqueuer, provided by the TaskEnqueuerBuilderExtension extension
Enqueues a name-based task from a DTO and persists a schemaversionbeside the JSON payload. -
getGroupStatus(
String groupId) → Future< GroupStatus?> -
Reads the latest group status by group id.
inherited
-
getTaskStatus(
String taskId) → Future< TaskStatus?> -
Reads the latest task status by task id.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForTask<
TResult extends Object?> (String taskId, {Duration? timeout, TResult decode(Object? payload)?, TResult decodeJson(Map< String, dynamic> payload)?, TResult decodeVersionedJson(Map<String, dynamic> payload, int version)?}) → Future<TaskResult< TResult> ?> -
Waits for a task result by task id.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited