TaskSignature<T extends Object?> class
Describes a task to schedule along with optional decoder metadata.
Constructors
- TaskSignature.custom(String name, Envelope builder(), {T decode(Object? payload)?})
-
Creates a signature from a custom envelope builder.
factory
Properties
- decode → T Function(Object? payload)?
-
Optional decoder that transforms backend payloads into typed values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Logical task name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
) → Envelope - Builds an Envelope for this task.
-
decodePayload(
Object? payload) → T? -
Decodes
payloadif a decoder is configured, otherwise performs a simple cast. Returnsnullwhenpayloadisnull. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited