TaskStatus class
Canonical task record stored in the result backend.
Constructors
Properties
- attempt → int
-
The attempt number for this task execution.
final
- error → TaskError?
-
The error that occurred during task execution, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier for this task status.
final
-
meta
→ Map<
String, Object?> -
Additional metadata for this task status.
final
- payload → Object?
-
The payload associated with this task, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TaskState
-
The current state of this task.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes this status to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited