TaskStatusRecord class
Immutable record representing a persisted task status with timestamps.
Constructors
- TaskStatusRecord({required TaskStatus status, required DateTime createdAt, required DateTime updatedAt})
-
Creates a task status record.
const
Properties
- createdAt → DateTime
-
Timestamp when the task status was first persisted.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TaskStatus
-
Task status payload.
final
- updatedAt → DateTime
-
Timestamp when the task status was last updated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited