TaskSuccessPayload class
Payload emitted when a task completes successfully.
Constructors
- TaskSuccessPayload({required Envelope envelope, required WorkerInfo worker, required Object? result})
-
Creates a new TaskSuccessPayload instance.
const
Properties
- attempt → int
-
The attempt number for this task execution.
no setter
- envelope → Envelope
-
The task envelope that completed successfully.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → Object?
-
The result returned by the successful task.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
The unique identifier for the task.
no setter
- taskName → String
-
The name of the task.
no setter
- worker → WorkerInfo
-
The worker that executed the task.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited