WorkerHeartbeatPayload class
Payload emitted when a worker sends a heartbeat.
- Implemented types
Constructors
- WorkerHeartbeatPayload({required WorkerInfo worker, required DateTime timestamp})
-
Creates a new WorkerHeartbeatPayload instance.
const
Properties
-
attributes
→ Map<
String, Object?> -
Event attributes for diagnostics/observability.
no setteroverride
- eventName → String
-
Canonical event name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- occurredAt → DateTime
-
Timestamp when the event occurred.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
The timestamp when the heartbeat was sent.
final
- worker → WorkerInfo
-
The worker sending the heartbeat.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited