WorkerLifecyclePayload class
Payload emitted for worker lifecycle events (start, stop, etc.).
- Implemented types
Constructors
- WorkerLifecyclePayload({required WorkerInfo worker, String? reason, String signalName = 'worker-lifecycle', DateTime? timestamp})
- Creates a new WorkerLifecyclePayload instance.
Properties
-
attributes
→ Map<
String, Object?> -
Event attributes for diagnostics/observability.
no setteroverride
- eventName → String
-
Canonical event name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- occurredAt → DateTime
-
Timestamp when the event occurred.
no setteroverride
- reason → String?
-
Optional reason for the lifecycle event (e.g., shutdown reason).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signalName → String
-
Canonical signal name for this lifecycle event.
final
- worker → WorkerInfo
-
The worker involved in the lifecycle event.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited