WorkflowManifestEntry class
Immutable manifest entry describing a workflow definition.
Constructors
-
WorkflowManifestEntry({required String id, required String name, required WorkflowDefinitionKind kind, String? version, String? description, Map<
String, Object?> ? metadata, List<WorkflowManifestFlowStep> steps = const [], List<WorkflowManifestCheckpoint> checkpoints = const []}) -
Creates a workflow manifest entry.
const
Properties
-
checkpoints
→ List<
WorkflowManifestCheckpoint> -
Declared script checkpoints.
final
- declaredNodeLabel → String
-
Human-friendly label for the declared nodes on this workflow.
no setter
- description → String?
-
Optional workflow description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable workflow identifier.
final
- kind → WorkflowDefinitionKind
-
Workflow definition kind.
final
-
metadata
→ Map<
String, Object?> ? -
Optional workflow metadata.
final
- name → String
-
Workflow name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
WorkflowManifestFlowStep> -
Declared flow steps.
final
- version → String?
-
Optional workflow version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes this entry to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited