WorkflowStep class
Marks a workflow class method as a durable step.
Constructors
-
WorkflowStep({String? name, bool autoVersion = false, String? title, WorkflowStepKind kind = WorkflowStepKind.task, List<
String> taskNames = const [], Map<String, Object?> ? metadata}) -
Creates a workflow step annotation.
const
Properties
- autoVersion → bool
-
Whether the runtime should auto-version the step per iteration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → WorkflowStepKind
-
Step kind used for introspection.
final
-
metadata
→ Map<
String, Object?> ? -
Optional metadata attached to the step definition.
final
- name → String?
-
Optional override for the step name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
taskNames
→ List<
String> -
Optional task names associated with this step.
final
- title → String?
-
Optional human-friendly title for the step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited